#line 2 "php_lexer.c"

#line 4 "php_lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 33
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE phprestart(phpin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int phpleng;

extern FILE *phpin, *phpout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE phplex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-phplineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < phpleng; ++yyl )\
                    if ( phptext[yyl] == '\n' )\
                        --phplineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up phptext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up phptext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via phprestart()), so that the user can continue scanning by
	 * just pointing phpin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when phptext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int phpleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow phpwrap()'s to do buffer switches
 * instead of setting up a fresh phpin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void phprestart (FILE *input_file  );
void php_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE php_create_buffer (FILE *file,int size  );
void php_delete_buffer (YY_BUFFER_STATE b  );
void php_flush_buffer (YY_BUFFER_STATE b  );
void phppush_buffer_state (YY_BUFFER_STATE new_buffer  );
void phppop_buffer_state (void );

static void phpensure_buffer_stack (void );
static void php_load_buffer_state (void );
static void php_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER php_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE php_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE php_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE php_scan_bytes (yyconst char *bytes,int len  );

void *phpalloc (yy_size_t  );
void *phprealloc (void *,yy_size_t  );
void phpfree (void *  );

#define yy_new_buffer php_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        phpensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            php_create_buffer(phpin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        phpensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            php_create_buffer(phpin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

typedef unsigned char YY_CHAR;

FILE *phpin = (FILE *) 0, *phpout = (FILE *) 0;

typedef int yy_state_type;

extern int phplineno;

int phplineno = 1;

extern char *phptext;
#define yytext_ptr phptext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up phptext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	(yytext_ptr) -= (yy_more_len); \
	phpleng = (size_t) (yy_cp - (yytext_ptr)); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 79
#define YY_END_OF_BUFFER 80
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[276] =
    {   0,
        0,    0,    0,    0,    0,    0,   59,   59,   80,   78,
       77,   77,   78,   78,   65,   78,   78,   78,   78,   78,
       78,   78,   78,   78,   78,   73,   73,   78,   78,   78,
       78,   71,   78,   71,   71,   71,   71,   71,   71,   71,
       71,   71,   71,   71,   71,   71,   71,   71,   71,   78,
       79,   79,   66,   67,   67,   59,   79,   53,    0,   75,
        0,   70,   44,   38,   45,    0,   76,    0,    0,    0,
        0,    0,    0,    0,    0,   41,   31,   39,   32,   40,
       28,   74,   43,   68,   65,   42,   74,   73,    0,    0,
       54,    0,   52,   33,   55,    0,    2,   71,   47,   71,

       71,   17,   71,   71,   71,   71,   71,   13,   71,   71,
       71,   71,   71,   71,   71,    7,   71,   71,   71,   34,
       71,   71,   71,   71,   71,   71,   46,   37,   69,   66,
       67,   59,    0,    0,   70,    0,    0,    0,    0,    0,
        0,   74,   72,   48,    0,   50,   49,   36,   71,   71,
       71,   71,   71,    3,   71,   71,   71,   71,   14,   71,
       71,   71,   71,   27,   71,   71,   71,   71,   71,   35,
       60,    0,   51,    0,    0,    0,    0,    0,    0,    0,
       71,   71,   21,   71,   71,   71,   25,    8,   71,   71,
       71,   71,   71,   71,   71,   71,   29,   71,   71,   71,

       71,   71,    0,    0,    0,    0,   61,    0,    0,    0,
        1,   30,   23,    5,   71,   71,   71,   71,   10,   71,
       71,   71,   71,   71,   71,   26,   71,   71,   71,   11,
        0,   64,    0,    0,    0,    0,   62,    0,   71,   71,
        9,   15,   71,   71,   71,   71,   56,   71,    6,   57,
       19,    0,    0,    0,   71,   22,   71,   71,   71,   16,
       71,   58,    0,    0,    0,   63,   24,   71,   71,   12,
        4,   71,   20,   18,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    5,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,    1,   17,   18,   19,   20,   21,   21,
       21,   21,   21,   21,   21,   21,   21,    1,    1,   22,
       23,   24,   25,    1,   26,   26,   26,   26,   26,   26,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
        1,   28,    1,   29,   27,    1,   30,   31,   32,   33,

       34,   35,   36,   37,   38,   27,   39,   40,   27,   41,
       42,   43,   27,   44,   45,   46,   47,   27,   48,   49,
       50,   27,    1,   51,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[52] =
    {   0,
        1,    1,    2,    1,    2,    1,    1,    1,    1,    1,
        1,    3,    1,    1,    1,    1,    3,    3,    1,    4,
        4,    1,    1,    1,    1,    5,    6,    1,    1,    5,
        5,    5,    5,    5,    5,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        1
    } ;

static yyconst flex_int16_t yy_base[287] =
    {   0,
        0,    0,  343,  342,   49,   50,   54,   55,  356,  359,
      359,  359,  332,   51,  359,    0,  331,   48,   48,   59,
      330,   46,   51,   57,   66,   52,   66,   73,   40,   59,
      328,    0,  328,   61,  306,   58,   73,   76,   67,  309,
       58,  310,  313,  302,  301,  310,   64,  306,  300,   68,
      359,  322,    0,  359,  337,  337,    0,  315,  106,  359,
      334,    0,  359,  359,  359,  108,  359,  333,  116,  293,
      292,  293,  291,  297,  284,  359,  359,  359,  359,  359,
      359,  101,  359,  359,  359,  359,  103,  108,    0,  306,
      359,  285,  304,  359,  359,  303,  359,    0,  359,  292,

      280,    0,  289,  277,  280,  285,  285,    0,  281,  272,
      283,  277,  270,  272,  270,    0,  279,  265,  261,    0,
      270,  261,  276,  267,  266,  259,  359,  359,  359,    0,
      359,  300,  289,  277,    0,  257,  251,  255,  250,  265,
      250,  110,    0,  359,  256,  359,  359,    0,  262,  261,
      256,   87,  259,    0,  246,  253,  100,  240,  251,  252,
      252,  242,  235,    0,  239,  232,  232,  231,  236,    0,
      359,  263,  359,  234,  242,  242,  125,  231,  232,  226,
      218,  228,    0,  220,  227,  217,    0,  225,  220,  226,
      212,  222,  228,  211,  226,  208,    0,  208,  209,  214,

      219,  216,  138,  209,  202,  139,  359,  211,  141,  205,
      359,    0,    0,    0,  204,  204,  208,  198,    0,  203,
      202,  207,  200,  197,  203,    0,  194,  202,  196,    0,
      142,  359,  202,  197,  196,  144,  359,  193,  181,  181,
        0,  192,  179,  184,  186,  165,    0,  140,    0,    0,
        0,  132,  127,  148,  136,    0,  138,  135,  132,    0,
      124,    0,  155,  161,  162,  359,    0,  110,  100,    0,
        0,   28,    0,    0,  359,  176,  182,  188,  190,  196,
      199,  205,  207,  210,  213,  216
    } ;

static yyconst flex_int16_t yy_def[287] =
    {   0,
      275,    1,  276,  276,  277,  277,  276,  276,  275,  275,
      275,  275,  275,  278,  275,  279,  275,  275,  280,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  281,  275,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  275,
      275,  275,  282,  275,  275,  275,  283,  275,  278,  275,
      278,  284,  275,  275,  275,  280,  275,  280,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  285,  275,
      275,  275,  275,  275,  275,  275,  275,  281,  275,  281,

      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  275,  275,  275,  282,
      275,  275,  286,  275,  284,  275,  275,  275,  275,  275,
      275,  275,  285,  275,  275,  275,  275,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      275,  286,  275,  275,  275,  275,  275,  275,  275,  275,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,

      281,  281,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      275,  275,  275,  275,  275,  275,  275,  275,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  275,  275,  275,  281,  281,  281,  281,  281,  281,
      281,  281,  275,  275,  275,  275,  281,  281,  281,  281,
      281,  281,  281,  281,    0,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275
    } ;

static yyconst flex_int16_t yy_nxt[411] =
    {   0,
       10,   11,   12,   11,   11,   13,   14,   15,   16,   17,
       18,   19,   20,   10,   21,   22,   23,   24,   25,   26,
       27,   28,   29,   30,   31,   32,   32,   10,   33,   34,
       35,   36,   37,   38,   39,   40,   32,   41,   32,   42,
       43,   44,   45,   46,   47,   32,   32,   48,   49,   32,
       50,   54,   54,   55,   55,   56,   56,   60,   64,   67,
       69,   77,   93,   94,  274,   57,   57,   79,   78,   87,
       65,   88,   88,   80,   81,   68,   82,   82,   61,   83,
       84,   95,   96,   87,   85,   88,   88,  104,   86,   70,
      127,   71,  116,   72,   90,   91,   73,   92,  117,  105,

       89,  100,   74,   75,  101,  102,  106,  109,  113,  123,
      107,  124,   60,  114,  108,  110,  111,   69,  128,   67,
       82,   82,  142,  142,  112,   87,  206,   88,   88,  142,
      142,  184,  185,   61,  189,   68,  273,  190,  207,  231,
      206,  272,  236,  231,  191,  236,   70,  192,   71,  265,
       72,  232,  207,   73,  237,  232,  231,  237,  208,   74,
       75,  266,  206,  265,  271,  270,  269,  268,  232,  267,
      264,  233,  263,  262,  207,  266,   51,   51,   51,   51,
       51,   51,   53,   53,   53,   53,   53,   53,   59,   59,
       59,   59,   59,   59,   62,   62,   66,   66,   66,   66,

       66,   66,   98,   98,   98,  130,  261,  130,  130,  130,
      130,  133,  133,  135,  135,  135,  143,  143,  172,  172,
      172,  172,  260,  259,  258,  257,  256,  255,  254,  253,
      209,  252,  251,  250,  249,  248,  247,  246,  245,  244,
      243,  242,  241,  240,  239,  238,  235,  209,  234,  230,
      229,  228,  227,  226,  225,  224,  223,  222,  221,  220,
      219,  218,  217,  216,  215,  214,  213,  212,  211,  210,
      209,  205,  204,  203,  171,  202,  201,  200,  199,  198,
      197,  196,  195,  194,  193,  154,  188,  187,  186,  183,
      182,  181,  180,  179,  178,  177,  176,  175,  174,  173,

      171,  132,  170,  169,  168,  167,  166,  165,  164,  163,
      162,  161,  160,  159,  158,  157,  156,  155,  154,  153,
      152,  151,  150,  149,  148,  147,  146,  145,  144,  141,
      140,  139,  138,  137,  136,  275,  275,  134,  132,  131,
      129,  126,  125,  122,  121,  120,  119,  118,  115,  103,
       99,   97,   76,   63,   58,  275,   52,   52,    9,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,

      275,  275,  275,  275,  275,  275,  275,  275,  275,  275
    } ;

static yyconst flex_int16_t yy_chk[411] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    5,    6,    7,    8,   14,   18,   19,
       20,   22,   29,   29,  272,    7,    8,   23,   22,   26,
       18,   26,   26,   23,   23,   19,   24,   24,   14,   24,
       25,   30,   30,   27,   25,   27,   27,   36,   25,   20,
       50,   20,   41,   20,   28,   28,   20,   28,   41,   36,

       26,   34,   20,   20,   34,   34,   37,   38,   39,   47,
       37,   47,   59,   39,   37,   38,   38,   69,   50,   66,
       82,   82,   87,   87,   38,   88,  177,   88,   88,  142,
      142,  152,  152,   59,  157,   66,  269,  157,  177,  203,
      206,  268,  209,  231,  157,  236,   69,  157,   69,  254,
       69,  203,  206,   69,  209,  231,  263,  236,  177,   69,
       69,  254,  264,  265,  261,  259,  258,  257,  263,  255,
      253,  203,  252,  248,  264,  265,  276,  276,  276,  276,
      276,  276,  277,  277,  277,  277,  277,  277,  278,  278,
      278,  278,  278,  278,  279,  279,  280,  280,  280,  280,

      280,  280,  281,  281,  281,  282,  246,  282,  282,  282,
      282,  283,  283,  284,  284,  284,  285,  285,  286,  286,
      286,  286,  245,  244,  243,  242,  240,  239,  238,  235,
      234,  233,  229,  228,  227,  225,  224,  223,  222,  221,
      220,  218,  217,  216,  215,  210,  208,  205,  204,  202,
      201,  200,  199,  198,  196,  195,  194,  193,  192,  191,
      190,  189,  188,  186,  185,  184,  182,  181,  180,  179,
      178,  176,  175,  174,  172,  169,  168,  167,  166,  165,
      163,  162,  161,  160,  159,  158,  156,  155,  153,  151,
      150,  149,  145,  141,  140,  139,  138,  137,  136,  134,

      133,  132,  126,  125,  124,  123,  122,  121,  119,  118,
      117,  115,  114,  113,  112,  111,  110,  109,  107,  106,
      105,  104,  103,  101,  100,   96,   93,   92,   90,   75,
       74,   73,   72,   71,   70,   68,   61,   58,   56,   55,
       52,   49,   48,   46,   45,   44,   43,   42,   40,   35,
       33,   31,   21,   17,   13,    9,    4,    3,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,

      275,  275,  275,  275,  275,  275,  275,  275,  275,  275
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[80] =
    {   0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 
        };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int php_flex_debug;
int php_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
static int yy_more_flag = 0;
static int yy_more_len = 0;
#define yymore() ((yy_more_flag) = 1)
#define YY_MORE_ADJ (yy_more_len)
#define YY_RESTORE_YY_MORE_OFFSET
char *phptext;
#line 1 "php_lexer.l"
#line 2 "php_lexer.l"
//
// This file is part of the aMule Project.
//
// Copyright (c) 2003-2011 aMule Team ( admin@amule.org / http://www.amule.org )
// Copyright (c) 2005-2011 Froenchenko Leonid ( lfroen@gmail.com / http://www.amule.org )
//
// Any parts of this program derived from the xMule, lMule or eMule project,
// or contributed by third-party developers are copyrighted by their
// respective authors.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
//

#include <string.h>

#include "php_syntree.h"
#include "php_parser.h"

void php_set_input_buffer(char *buf, int len)
{
	php_delete_buffer(YY_CURRENT_BUFFER);
	php_scan_bytes(buf,len);
}

int phpwrap();


#define MAX_INCLUDE_DEPTH 10
YY_BUFFER_STATE php_include_stack[MAX_INCLUDE_DEPTH];
int php_include_stack_ptr = 0;

int phpwrap()
{
	if ( --php_include_stack_ptr < 0 ) {
		return 1;
	} else {
		php_delete_buffer(YY_CURRENT_BUFFER );
		php_switch_to_buffer(php_include_stack[php_include_stack_ptr] );
	}
	return 0;
}




#line 717 "php_lexer.c"

#define INITIAL 0
#define BLOCK_COMMENT 1
#define LINE_COMMENT 2
#define INCLUDE 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int phpwrap (void );
#else
extern int phpwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
    static int yy_top_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( phptext, phpleng, 1, phpout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( phpin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( phpin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, phpin))==0 && ferror(phpin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(phpin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int phplex (void);

#define YY_DECL int phplex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after phptext and phpleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 73 "php_lexer.l"


#line 886 "php_lexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! phpin )
			phpin = stdin;

		if ( ! phpout )
			phpout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			phpensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				php_create_buffer(phpin,YY_BUF_SIZE );
		}

		php_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		(yy_more_len) = 0;
		if ( (yy_more_flag) )
			{
			(yy_more_len) = (yy_c_buf_p) - (yytext_ptr);
			(yy_more_flag) = 0;
			}
		yy_cp = (yy_c_buf_p);

		/* Support of phptext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 276 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 359 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = (yy_more_len); yyl < phpleng; ++yyl )
				if ( phptext[yyl] == '\n' )
					   
    phplineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 75 "php_lexer.l"
return START_SCRIPT;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 76 "php_lexer.l"
return END_SCRIPT;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 78 "php_lexer.l"
return EXIT;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 80 "php_lexer.l"
return FUNCTION;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 82 "php_lexer.l"
return CONST;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 84 "php_lexer.l"
return RETURN;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 86 "php_lexer.l"
return IF;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 87 "php_lexer.l"
return ELSE;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 88 "php_lexer.l"
return ELSEIF;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 89 "php_lexer.l"
return ENDIF;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 91 "php_lexer.l"
return WHILE;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 92 "php_lexer.l"
return ENDWHILE;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 93 "php_lexer.l"
return DO;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 95 "php_lexer.l"
return FOR;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 96 "php_lexer.l"
return ENDFOR;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 97 "php_lexer.l"
return FOREACH;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 98 "php_lexer.l"
return AS;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 99 "php_lexer.l"
return ENDFOREACH;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 101 "php_lexer.l"
return SWITCH;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 102 "php_lexer.l"
return ENDSWITCH;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 103 "php_lexer.l"
return CASE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 104 "php_lexer.l"
return DEFAULT;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 105 "php_lexer.l"
return BREAK;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 107 "php_lexer.l"
return CONTINUE;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 109 "php_lexer.l"
return T_ECHO;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 110 "php_lexer.l"
return PRINT;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 112 "php_lexer.l"
return NEW;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 114 "php_lexer.l"
return OBJECT_OPERATOR;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 116 "php_lexer.l"
return LIST;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 117 "php_lexer.l"
return ARRAY;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 119 "php_lexer.l"
return INC;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 120 "php_lexer.l"
return DEC;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 121 "php_lexer.l"
return HASH_ASSIGN;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 123 "php_lexer.l"
return LOG_OR;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 124 "php_lexer.l"
return LOG_XOR;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 125 "php_lexer.l"
return LOG_AND;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 126 "php_lexer.l"
return BOOLEAN_OR;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 127 "php_lexer.l"
return BOOLEAN_AND;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 129 "php_lexer.l"
return PLUS_EQ;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 130 "php_lexer.l"
return MINUS_EQ;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 131 "php_lexer.l"
return MUL_EQ;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 132 "php_lexer.l"
return DIV_EQ;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 133 "php_lexer.l"
return CONCAT_EQ;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 134 "php_lexer.l"
return MOD_EQ;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 135 "php_lexer.l"
return AND_EQ;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 136 "php_lexer.l"
return OR_EQ;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 137 "php_lexer.l"
return XOR_EQ;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 138 "php_lexer.l"
return SL_EQ;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 139 "php_lexer.l"
return SR_EQ;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 141 "php_lexer.l"
return IS_IDENTICAL;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 142 "php_lexer.l"
return IS_NOIDENTICAL;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 143 "php_lexer.l"
return IS_EQ;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 144 "php_lexer.l"
return IS_NOEQUAL;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 145 "php_lexer.l"
return IS_SMALLER_OR_EQ;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 146 "php_lexer.l"
return IS_GREATER_OR_EQ;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 148 "php_lexer.l"
return GLOBAL;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 149 "php_lexer.l"
return STATIC;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 151 "php_lexer.l"
BEGIN(INCLUDE);
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 152 "php_lexer.l"

	YY_BREAK
case 60:
YY_RULE_SETUP
#line 153 "php_lexer.l"
{
	phptext[strlen(phptext)-1] = 0;
	if ( php_include_stack_ptr >= MAX_INCLUDE_DEPTH ) {
		fprintf( stderr, "WARNING: maximum include depth (which is %d) exceed", MAX_INCLUDE_DEPTH);
	} else {
		php_include_stack[php_include_stack_ptr++] = YY_CURRENT_BUFFER;
		phpin = fopen(phptext+1, "r");
		if ( !phpin ) {
			printf("WARNING: include file [%s] can not be opened\n", phptext+1);
		} else {
			php_switch_to_buffer(php_create_buffer(phpin,YY_BUF_SIZE ));
		}
	}
        BEGIN(INITIAL);
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 169 "php_lexer.l"
{
        return INT_CAST;
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 173 "php_lexer.l"
{
        return DOUBLE_CAST;
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 177 "php_lexer.l"
{
        return STRING_CAST;
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 181 "php_lexer.l"
{
        return BOOL_CAST;
}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 185 "php_lexer.l"
{
		BEGIN(LINE_COMMENT);
		yymore();
	}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 190 "php_lexer.l"
{
		yymore();
	}
	YY_BREAK
case 67:
/* rule 67 can match eol */
YY_RULE_SETUP
#line 194 "php_lexer.l"
{
		BEGIN(INITIAL);
	}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 198 "php_lexer.l"
{
		BEGIN(BLOCK_COMMENT);
		yymore();
	}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 203 "php_lexer.l"
{
		BEGIN(INITIAL);
	}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 207 "php_lexer.l"
{
        phplval.exp_node = get_var_node(phptext+1);
        return VARIABLE;
	}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 212 "php_lexer.l"
{
        strcpy(phplval.str_val, phptext);
        return IDENT;
	}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 217 "php_lexer.l"
{
	int val;
	sscanf(phptext, "0x%x", &val);
	phplval.exp_node = make_const_exp_dnum(val);
	return DNUMBER;
	}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 224 "php_lexer.l"
{
	phplval.exp_node = make_const_exp_dnum(atoi(phptext));
	return DNUMBER;
	}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 229 "php_lexer.l"
{
	phplval.exp_node = make_const_exp_fnum(atof(phptext));
	return FNUMBER;
	}
	YY_BREAK
case 75:
/* rule 75 can match eol */
YY_RULE_SETUP
#line 234 "php_lexer.l"
{
		phptext[strlen(phptext)-1] = 0;
		phplval.exp_node = make_const_exp_str(phptext+1, 1);
		return STRING;
}
	YY_BREAK
case 76:
/* rule 76 can match eol */
YY_RULE_SETUP
#line 240 "php_lexer.l"
{
		phptext[strlen(phptext)-1] = 0;
		phplval.exp_node = make_const_exp_str(phptext+1, 0);
		return STRING;
}
	YY_BREAK
case 77:
/* rule 77 can match eol */
YY_RULE_SETUP
#line 246 "php_lexer.l"
{  }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 248 "php_lexer.l"
{
		return phptext[0];
}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 251 "php_lexer.l"
ECHO;
	YY_BREAK
#line 1445 "php_lexer.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(BLOCK_COMMENT):
case YY_STATE_EOF(LINE_COMMENT):
case YY_STATE_EOF(INCLUDE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed phpin at a new source and called
			 * phplex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = phpin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( phpwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * phptext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of phplex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					phprealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			phprestart(phpin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 276 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 276 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 275);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up phptext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --phplineno;
    }

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					phprestart(phpin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( phpwrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve phptext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    phplineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void phprestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        phpensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            php_create_buffer(phpin,YY_BUF_SIZE );
	}

	php_init_buffer(YY_CURRENT_BUFFER,input_file );
	php_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void php_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		phppop_buffer_state();
	 *		phppush_buffer_state(new_buffer);
     */
	phpensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	php_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (phpwrap()) processing, but the only time this flag
	 * is looked at is after phpwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void php_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	phpin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE php_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) phpalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in php_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) phpalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in php_create_buffer()" );

	b->yy_is_our_buffer = 1;

	php_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with php_create_buffer()
 * 
 */
    void php_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		phpfree((void *) b->yy_ch_buf  );

	phpfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a phprestart() or at EOF.
 */
    static void php_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	php_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then php_init_buffer was _probably_
     * called from phprestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void php_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		php_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void phppush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	phpensure_buffer_stack();

	/* This block is copied from php_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from php_switch_to_buffer. */
	php_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void phppop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	php_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		php_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void phpensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)phpalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)phprealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE php_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) phpalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in php_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	php_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to phplex() will
 * scan from a @e copy of @a str.
 * @param str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       php_scan_bytes() instead.
 */
YY_BUFFER_STATE php_scan_string (yyconst char * yystr )
{
    
	return php_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to phplex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE php_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) phpalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in php_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = php_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in php_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) phpalloc(new_size  );

		else
			(yy_start_stack) = (int *) phprealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR(
			"out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up phptext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		phptext[phpleng] = (yy_hold_char); \
		(yy_c_buf_p) = phptext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		phpleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int phpget_lineno  (void)
{
        
    return phplineno;
}

/** Get the input stream.
 * 
 */
FILE *phpget_in  (void)
{
        return phpin;
}

/** Get the output stream.
 * 
 */
FILE *phpget_out  (void)
{
        return phpout;
}

/** Get the length of the current token.
 * 
 */
int phpget_leng  (void)
{
        return phpleng;
}

/** Get the current token.
 * 
 */

char *phpget_text  (void)
{
        return phptext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void phpset_lineno (int  line_number )
{
    
    phplineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see php_switch_to_buffer
 */
void phpset_in (FILE *  in_str )
{
        phpin = in_str ;
}

void phpset_out (FILE *  out_str )
{
        phpout = out_str ;
}

int phpget_debug  (void)
{
        return php_flex_debug;
}

void phpset_debug (int  bdebug )
{
        php_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from phplex_destroy(), so don't allocate here.
     */

    /* We do not touch phplineno unless the option is enabled. */
    phplineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    phpin = stdin;
    phpout = stdout;
#else
    phpin = (FILE *) 0;
    phpout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * phplex_init()
     */
    return 0;
}

/* phplex_destroy is for both reentrant and non-reentrant scanners. */
int phplex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		php_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		phppop_buffer_state();
	}

	/* Destroy the stack itself. */
	phpfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        phpfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * phplex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *phpalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *phprealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void phpfree (void * ptr )
{
	free( (char *) ptr );	/* see phprealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 251 "php_lexer.l"
